// (C) 2024 GoodData Corporation
/**
 * Dummy query builder for semantic search testing
 * @internal
 */
export class DummySemanticSearchQueryBuilder {
    workspaceId;
    constructor(workspaceId) {
        this.workspaceId = workspaceId;
    }
    question = "";
    withQuestion(question) {
        this.question = question;
        return this;
    }
    withLimit() {
        return this;
    }
    withObjectTypes() {
        return this;
    }
    withDeepSearch() {
        return this;
    }
    async query({ signal } = {}) {
        await cancellableTimeout(100, signal);
        return {
            results: [
                "dataset",
                "attribute",
                "label",
                "fact",
                "date",
                "metric",
                "visualization",
                "dashboard",
            ].map((type) => ({
                id: type,
                type: type,
                workspaceId: this.workspaceId,
                title: `${type} title`,
                description: this.question,
                tags: [],
                createdAt: "2023-08-03T13:17:26.923537",
                modifiedAt: "2023-08-03T13:17:26.923537",
                visualizationUrl: type === "visualization" ? "local:line" : undefined,
                score: 0.5,
                scoreTitle: 0.5,
                scoreDescriptor: 0.5,
                scoreExactMatch: 0,
            })),
            relationships: [],
        };
    }
}
const cancellableTimeout = async (ms, signal) => {
    return new Promise((res, rej) => {
        if (signal?.aborted) {
            rej(signal.reason);
        }
        signal?.addEventListener("abort", () => rej(signal.reason));
        setTimeout(res, ms);
    });
};
//# sourceMappingURL=DummySemanticSearch.js.map